======
Common
======

Common is a Django library that provides some reusable components.

Installation
------------

.. code-block:: sh

    $ pip install fh-django-common

Running tests
-------------

.. code-block:: sh

    $ python setup.py test

Usage
-----

TODO